// -*- tab-width:4 -*-

/**
   CTGRWindowPlacementDlgクラスの実装。
**/

#include <WSCmainWindow.h>
#include <WSCtform.h>
#include <WSCvlabel.h>
#include <WSCvradio.h>

#include "TGRWindowPlacementDlg.hpp"

#include "TGRApp.hpp"
#include "TGRRelWordWin.hpp"
#include "TGRWordFinderPanel.hpp"

#include "ALUtGUI.hpp"

#include <string>
#include <vector>
#include <algorithm>

namespace tgrapp {

class CTGRWindowPlacementDlg::WPDImpl {
    friend class CTGRWindowPlacementDlg;

    WPDImpl() { Clear(); }
    ~WPDImpl() { Delete(); Clear(); }

    void CreateParts();
    void SetupVectors();
    void SetupEventProcedures();

    void Clear();
    void Delete();

    /** チェックボタン選択時の処理。 */
    void OnRadValueChanged(WSCbase* object);

    /** ボタングループを示す vector を返す。*/
    std::vector<WSCvradio*>* GetSelectedBtnGroup(WSCbase* object);

    /** チェックボタン選択時に呼び出されるイベントプロシージャ */
    static void ep_rad_value_ch(WSCbase* object);

private:
    /** チェックボタン選択時の処理中であることを示すフラグ（再入阻止のため）。 */
    bool _in_rad_value_ch_proc;

    /** オブジェクトとインスタンスを結びつけるためのマップ変数を宣言。 */
    static al::gui::ObjectInstanceMap<WSCbase,WPDImpl>	m_oi_map;
    


/**@name パーツを集合的に扱うためのvector */
/*@{*/
    std::vector<WSCvradio*>	_rad_mw_w;
    std::vector<WSCvradio*>	_rad_mw_h;
    std::vector<WSCvradio*>	_rad_sp_w;
    std::vector<WSCvradio*>	_rad_sp_h;
    std::vector<WSCvradio*>	_rad_iw_w;
    std::vector<WSCvradio*>	_rad_iw_h;
    std::vector<WSCvradio*>	_rad_sp_p;
    std::vector<WSCvradio*>	_rad_iw_p;
/*@}*/

    /* 以下はパーツ */

    WSCmainWindow* WPDImplMain;

    WSCtform* WPDtfor_main_window_size;
    WSCvlabel* WPDvlab_mw_w;
    WSCvlabel* WPDvlab_mw_h;
    WSCvradio* WPDvrad_mw_w_w;
    WSCvradio* WPDvrad_mw_w_mw;
    WSCvradio* WPDvrad_mw_w_m;
    WSCvradio* WPDvrad_mw_w_mn;
    WSCvradio* WPDvrad_mw_w_n;
    WSCvradio* WPDvrad_mw_h_h;
    WSCvradio* WPDvrad_mw_h_mh;
    WSCvradio* WPDvrad_mw_h_m;
    WSCvradio* WPDvrad_mw_h_ml;
    WSCvradio* WPDvrad_mw_h_l;

    WSCtform* WPDtfor_search_panel_size;
    WSCvlabel* WPDvlab_sp_w;
    WSCvlabel* WPDvlab_sp_h;
    WSCvradio* WPDvrad_sp_w_w;
    WSCvradio* WPDvrad_sp_w_m;
    WSCvradio* WPDvrad_sp_w_n;
    WSCvradio* WPDvrad_sp_w_sam;
    WSCvradio* WPDvrad_sp_h_h;
    WSCvradio* WPDvrad_sp_h_m;
    WSCvradio* WPDvrad_sp_h_l;
    WSCvradio* WPDvrad_sp_h_sam;

    WSCtform* WPDtfor_info_window_size;
    WSCvlabel* WPDvlab_iw_w;
    WSCvlabel* WPDvlab_iw_h;
    WSCvradio* WPDvrad_iw_w_w;
    WSCvradio* WPDvrad_iw_w_m;
    WSCvradio* WPDvrad_iw_w_n;
    WSCvradio* WPDvrad_iw_w_sam;
    WSCvradio* WPDvrad_iw_h_h;
    WSCvradio* WPDvrad_iw_h_m;
    WSCvradio* WPDvrad_iw_h_l;
    WSCvradio* WPDvrad_iw_h_sam;

    WSCtform* WPDtfor_search_panel_pos;
    WSCvlabel* WPDvlab_main_win;
    WSCvradio* WPDvrad_sp_p_tl;
    WSCvradio* WPDvrad_sp_p_tc;
    WSCvradio* WPDvrad_sp_p_tr;
    WSCvradio* WPDvrad_sp_p_trr;
    WSCvradio* WPDvrad_sp_p_tll;
    WSCvradio* WPDvrad_sp_p_rt;
    WSCvradio* WPDvrad_sp_p_rc;
    WSCvradio* WPDvrad_sp_p_rb;
    WSCvradio* WPDvrad_sp_p_brr;
    WSCvradio* WPDvrad_sp_p_br;
    WSCvradio* WPDvrad_sp_p_bc;
    WSCvradio* WPDvrad_sp_p_bl;
    WSCvradio* WPDvrad_sp_p_bll;
    WSCvradio* WPDvrad_sp_p_lb;
    WSCvradio* WPDvrad_sp_p_lc;
    WSCvradio* WPDvrad_sp_p_lt;

    WSCtform* WPDtfor_info_window_pos;
    WSCvlabel* WPDvlab_iw_main_win;
    WSCvradio* WPDvrad_iw_p_tl;
    WSCvradio* WPDvrad_iw_p_tc;
    WSCvradio* WPDvrad_iw_p_tr;
    WSCvradio* WPDvrad_iw_p_trr;
    WSCvradio* WPDvrad_iw_p_tll;
    WSCvradio* WPDvrad_iw_p_rt;
    WSCvradio* WPDvrad_iw_p_rc;
    WSCvradio* WPDvrad_iw_p_rb;
    WSCvradio* WPDvrad_iw_p_brr;
    WSCvradio* WPDvrad_iw_p_br;
    WSCvradio* WPDvrad_iw_p_bc;
    WSCvradio* WPDvrad_iw_p_bl;
    WSCvradio* WPDvrad_iw_p_bll;
    WSCvradio* WPDvrad_iw_p_lb;
    WSCvradio* WPDvrad_iw_p_lc;
    WSCvradio* WPDvrad_iw_p_lt;
};


/**@name クラスの static 変数の定義 */
/*@{*/
al::gui::ObjectInstanceMap<WSCbase,CTGRWindowPlacementDlg::WPDImpl>
CTGRWindowPlacementDlg::WPDImpl::m_oi_map;
/*@}*/

void CTGRWindowPlacementDlg::WPDImpl::OnRadValueChanged(WSCbase* object)
{
    WSCvradio*	radio = dynamic_cast<WSCvradio*>(object);
    if( radio == 0 || radio->getStatus() != True )
        return;

    std::vector<WSCvradio*>*	group = GetSelectedBtnGroup(radio);
    if( group == 0 ) return;

    if( group == &_rad_sp_w || group == &_rad_sp_h || group == &_rad_sp_p )
        GetCTGRWFPanel()->ShowWFPanelWindow(true);
    if( group == &_rad_iw_w || group == &_rad_iw_h || group == &_rad_iw_p )
        GetCTGRRelWordWin()->ShowRWWindow(true);

    std::vector<WSCvradio*>::iterator	iit = std::find(group->begin(),group->end(),radio);
    size_t	index = iit - group->begin();

    /* 各グループ別の処理 */
    WSCmainWindow* main_win = GetTGRApp()->GetMainWindow();
    WSCmainWindow* search_panel = GetCTGRWFPanel()->GetMainWindow();
    WSCmainWindow* info_win = GetCTGRRelWordWin()->GetMainWindow();

    unsigned short main_w = main_win->getProperty(WSNwidth);
    unsigned short main_h = main_win->getProperty(WSNheight);
    const unsigned short width_list[] = { 1200, 1024, 800, 700, 580 };
    const unsigned short height_list[] = { 960, 800, 600, 400, 230 };

    if( group == &_rad_mw_w )
        GetTGRApp()->ResizeWindow(main_win,width_list[index],0);
    else if( group == &_rad_mw_h )
        GetTGRApp()->ResizeWindow(main_win,0,height_list[index]);
    else if( group == &_rad_sp_w )
        GetTGRApp()->ResizeWindow(search_panel, (index < 3 ? width_list[index+0] : main_w),0);
    else if( group == &_rad_sp_h )
        GetTGRApp()->ResizeWindow(search_panel,0, (index < 3 ? height_list[index+1] : main_h));
    else if( group == &_rad_iw_w )
        GetTGRApp()->ResizeWindow(info_win, (index < 3 ? width_list[index+1] : main_w),0);
    else if( group == &_rad_iw_h ) {
        GetCTGRRelWordWin()->Ref_AutoHeightFlag() = false;
        GetTGRApp()->ResizeWindow(info_win,0,(index < 3 ? height_list[index+2] : main_h));
    }
    else if( group == &_rad_sp_p || group == &_rad_iw_p ) {
        WSCstring	wsc_name_str = radio->getProperty(WSNname);
        std::string	name_str = wsc_name_str.getString();
        size_t	n = name_str.rfind("_") + 1;
        const std::string	position_str = name_str.substr(n);

        GetTGRApp()->StopWindowSynchronizer();
        GetTGRApp()->ReplaceWindow( (group == &_rad_sp_p ? search_panel : info_win),
                                    position_str );
        GetTGRApp()->GetReadyWindowSynchronizer();
    }
}

std::vector<WSCvradio*>*
CTGRWindowPlacementDlg::WPDImpl::GetSelectedBtnGroup(WSCbase* object)
{
    if( std::find(_rad_mw_w.begin(),_rad_mw_w.end(),object) != _rad_mw_w.end() )
        return &_rad_mw_w;
    if( std::find(_rad_mw_h.begin(),_rad_mw_h.end(),object) != _rad_mw_h.end() )
        return &_rad_mw_h;
    if( std::find(_rad_sp_w.begin(),_rad_sp_w.end(),object) != _rad_sp_w.end() )
        return &_rad_sp_w;
    if( std::find(_rad_sp_h.begin(),_rad_sp_h.end(),object) != _rad_sp_h.end() )
        return &_rad_sp_h;
    if( std::find(_rad_iw_w.begin(),_rad_iw_w.end(),object) != _rad_iw_w.end() )
        return &_rad_iw_w;
    if( std::find(_rad_iw_h.begin(),_rad_iw_h.end(),object) != _rad_iw_h.end() )
        return &_rad_iw_h;
    if( std::find(_rad_sp_p.begin(),_rad_sp_p.end(),object) != _rad_sp_p.end() )
        return &_rad_sp_p;
    if( std::find(_rad_iw_p.begin(),_rad_iw_p.end(),object) != _rad_iw_p.end() )
        return &_rad_iw_p;

    return 0;
}

void CTGRWindowPlacementDlg::WPDImpl::ep_rad_value_ch(WSCbase* object)
{
    WPDImpl*	pimpl = m_oi_map.RecallInstanceForTheObject(object);
    if( pimpl == 0 )
        return;

    if( pimpl->_in_rad_value_ch_proc )
        return;
    pimpl->_in_rad_value_ch_proc = true;
    pimpl->OnRadValueChanged(object);
    pimpl->_in_rad_value_ch_proc = false;
}

CTGRWindowPlacementDlg::CTGRWindowPlacementDlg()
{
    _pimpl = new WPDImpl;
    _pimpl->CreateParts();
    _pimpl->SetupVectors();
    _pimpl->SetupEventProcedures();
}

CTGRWindowPlacementDlg::~CTGRWindowPlacementDlg()
{
    Delete();
    _pimpl = 0;
}

void CTGRWindowPlacementDlg::ShowDialog(bool show)
{
    _pimpl->WPDImplMain->setVisible(show);
}

void CTGRWindowPlacementDlg::ToggleDialog()
{
    bool showing = _pimpl->WPDImplMain->getVisible();
    _pimpl->WPDImplMain->setVisible(!showing);
}

void CTGRWindowPlacementDlg::Delete()
{
    if( _pimpl )
        delete _pimpl;
    _pimpl = 0;
}

CTGRWindowPlacementDlg* GetCTGRWPDlg()
{
    static CTGRWindowPlacementDlg	dlg;

    return &dlg;
}

void CTGRWindowPlacementDlg::WPDImpl::Clear()
{
    _in_rad_value_ch_proc = false;

    WPDImplMain = NULL;

    WPDtfor_main_window_size = NULL;
    WPDvlab_mw_w = NULL;
    WPDvlab_mw_h = NULL;
    WPDvrad_mw_w_w = NULL;
    WPDvrad_mw_w_mw = NULL;
    WPDvrad_mw_w_m = NULL;
    WPDvrad_mw_w_mn = NULL;
    WPDvrad_mw_w_n = NULL;
    WPDvrad_mw_h_h = NULL;
    WPDvrad_mw_h_mh = NULL;
    WPDvrad_mw_h_m = NULL;
    WPDvrad_mw_h_ml = NULL;
    WPDvrad_mw_h_l = NULL;

    WPDtfor_search_panel_size = NULL;
    WPDvlab_sp_w = NULL;
    WPDvlab_sp_h = NULL;
    WPDvrad_sp_w_w = NULL;
    WPDvrad_sp_w_m = NULL;
    WPDvrad_sp_w_n = NULL;
    WPDvrad_sp_w_sam = NULL;
    WPDvrad_sp_h_h = NULL;
    WPDvrad_sp_h_m = NULL;
    WPDvrad_sp_h_l = NULL;
    WPDvrad_sp_h_sam = NULL;

    WPDtfor_info_window_size = NULL;
    WPDvlab_iw_w = NULL;
    WPDvlab_iw_h = NULL;
    WPDvrad_iw_w_w = NULL;
    WPDvrad_iw_w_m = NULL;
    WPDvrad_iw_w_n = NULL;
    WPDvrad_iw_w_sam = NULL;
    WPDvrad_iw_h_h = NULL;
    WPDvrad_iw_h_m = NULL;
    WPDvrad_iw_h_l = NULL;
    WPDvrad_iw_h_sam = NULL;

    WPDtfor_search_panel_pos = NULL;
    WPDvlab_main_win = NULL;
    WPDvrad_sp_p_tl = NULL;
    WPDvrad_sp_p_tc = NULL;
    WPDvrad_sp_p_tr = NULL;
    WPDvrad_sp_p_trr = NULL;
    WPDvrad_sp_p_tll = NULL;
    WPDvrad_sp_p_rt = NULL;
    WPDvrad_sp_p_rc = NULL;
    WPDvrad_sp_p_rb = NULL;
    WPDvrad_sp_p_brr = NULL;
    WPDvrad_sp_p_br = NULL;
    WPDvrad_sp_p_bc = NULL;
    WPDvrad_sp_p_bl = NULL;
    WPDvrad_sp_p_bll = NULL;
    WPDvrad_sp_p_lb = NULL;
    WPDvrad_sp_p_lc = NULL;
    WPDvrad_sp_p_lt = NULL;

    WPDtfor_info_window_pos = NULL;
    WPDvlab_iw_main_win = NULL;
    WPDvrad_iw_p_tl = NULL;
    WPDvrad_iw_p_tc = NULL;
    WPDvrad_iw_p_tr = NULL;
    WPDvrad_iw_p_trr = NULL;
    WPDvrad_iw_p_tll = NULL;
    WPDvrad_iw_p_rt = NULL;
    WPDvrad_iw_p_rc = NULL;
    WPDvrad_iw_p_rb = NULL;
    WPDvrad_iw_p_brr = NULL;
    WPDvrad_iw_p_br = NULL;
    WPDvrad_iw_p_bc = NULL;
    WPDvrad_iw_p_bl = NULL;
    WPDvrad_iw_p_bll = NULL;
    WPDvrad_iw_p_lb = NULL;
    WPDvrad_iw_p_lc = NULL;
    WPDvrad_iw_p_lt = NULL;
}

void CTGRWindowPlacementDlg::WPDImpl::Delete()
{
    if( WPDvlab_mw_w != 0 ) delete WPDvlab_mw_w;
    if( WPDvlab_mw_h != 0 ) delete WPDvlab_mw_h;
    if( WPDvrad_mw_w_w != 0 ) delete WPDvrad_mw_w_w;
    if( WPDvrad_mw_w_mw != 0 ) delete WPDvrad_mw_w_mw;
    if( WPDvrad_mw_w_m != 0 ) delete WPDvrad_mw_w_m;
    if( WPDvrad_mw_w_mn != 0 ) delete WPDvrad_mw_w_mn;
    if( WPDvrad_mw_w_n != 0 ) delete WPDvrad_mw_w_n;
    if( WPDvrad_mw_h_h != 0 ) delete WPDvrad_mw_h_h;
    if( WPDvrad_mw_h_mh != 0 ) delete WPDvrad_mw_h_mh;
    if( WPDvrad_mw_h_m != 0 ) delete WPDvrad_mw_h_m;
    if( WPDvrad_mw_h_ml != 0 ) delete WPDvrad_mw_h_ml;
    if( WPDvrad_mw_h_l != 0 ) delete WPDvrad_mw_h_l;

    if( WPDvlab_sp_w != 0 ) delete WPDvlab_sp_w;
    if( WPDvlab_sp_h != 0 ) delete WPDvlab_sp_h;
    if( WPDvrad_sp_w_w != 0 ) delete WPDvrad_sp_w_w;
    if( WPDvrad_sp_w_m != 0 ) delete WPDvrad_sp_w_m;
    if( WPDvrad_sp_w_n != 0 ) delete WPDvrad_sp_w_n;
    if( WPDvrad_sp_w_sam != 0 ) delete WPDvrad_sp_w_sam;
    if( WPDvrad_sp_h_h != 0 ) delete WPDvrad_sp_h_h;
    if( WPDvrad_sp_h_m != 0 ) delete WPDvrad_sp_h_m;
    if( WPDvrad_sp_h_l != 0 ) delete WPDvrad_sp_h_l;
    if( WPDvrad_sp_h_sam != 0 ) delete WPDvrad_sp_h_sam;

    if( WPDvlab_iw_w != 0 ) delete WPDvlab_iw_w;
    if( WPDvlab_iw_h != 0 ) delete WPDvlab_iw_h;
    if( WPDvrad_iw_w_w != 0 ) delete WPDvrad_iw_w_w;
    if( WPDvrad_iw_w_m != 0 ) delete WPDvrad_iw_w_m;
    if( WPDvrad_iw_w_n != 0 ) delete WPDvrad_iw_w_n;
    if( WPDvrad_iw_w_sam != 0 ) delete WPDvrad_iw_w_sam;
    if( WPDvrad_iw_h_h != 0 ) delete WPDvrad_iw_h_h;
    if( WPDvrad_iw_h_m != 0 ) delete WPDvrad_iw_h_m;
    if( WPDvrad_iw_h_l != 0 ) delete WPDvrad_iw_h_l;
    if( WPDvrad_iw_h_sam != 0 ) delete WPDvrad_iw_h_sam;

    if( WPDvlab_main_win != 0 ) delete WPDvlab_main_win;
    if( WPDvrad_sp_p_tl != 0 ) delete WPDvrad_sp_p_tl;
    if( WPDvrad_sp_p_tc != 0 ) delete WPDvrad_sp_p_tc;
    if( WPDvrad_sp_p_tr != 0 ) delete WPDvrad_sp_p_tr;
    if( WPDvrad_sp_p_trr != 0 ) delete WPDvrad_sp_p_trr;
    if( WPDvrad_sp_p_tll != 0 ) delete WPDvrad_sp_p_tll;
    if( WPDvrad_sp_p_rt != 0 ) delete WPDvrad_sp_p_rt;
    if( WPDvrad_sp_p_rc != 0 ) delete WPDvrad_sp_p_rc;
    if( WPDvrad_sp_p_rb != 0 ) delete WPDvrad_sp_p_rb;
    if( WPDvrad_sp_p_brr != 0 ) delete WPDvrad_sp_p_brr;
    if( WPDvrad_sp_p_br != 0 ) delete WPDvrad_sp_p_br;
    if( WPDvrad_sp_p_bc != 0 ) delete WPDvrad_sp_p_bc;
    if( WPDvrad_sp_p_bl != 0 ) delete WPDvrad_sp_p_bl;
    if( WPDvrad_sp_p_bll != 0 ) delete WPDvrad_sp_p_bll;
    if( WPDvrad_sp_p_lb != 0 ) delete WPDvrad_sp_p_lb;
    if( WPDvrad_sp_p_lc != 0 ) delete WPDvrad_sp_p_lc;
    if( WPDvrad_sp_p_lt != 0 ) delete WPDvrad_sp_p_lt;

    if( WPDvlab_iw_main_win != 0 ) delete WPDvlab_iw_main_win;
    if( WPDvrad_iw_p_tl != 0 ) delete WPDvrad_iw_p_tl;
    if( WPDvrad_iw_p_tc != 0 ) delete WPDvrad_iw_p_tc;
    if( WPDvrad_iw_p_tr != 0 ) delete WPDvrad_iw_p_tr;
    if( WPDvrad_iw_p_trr != 0 ) delete WPDvrad_iw_p_trr;
    if( WPDvrad_iw_p_tll != 0 ) delete WPDvrad_iw_p_tll;
    if( WPDvrad_iw_p_rt != 0 ) delete WPDvrad_iw_p_rt;
    if( WPDvrad_iw_p_rc != 0 ) delete WPDvrad_iw_p_rc;
    if( WPDvrad_iw_p_rb != 0 ) delete WPDvrad_iw_p_rb;
    if( WPDvrad_iw_p_brr != 0 ) delete WPDvrad_iw_p_brr;
    if( WPDvrad_iw_p_br != 0 ) delete WPDvrad_iw_p_br;
    if( WPDvrad_iw_p_bc != 0 ) delete WPDvrad_iw_p_bc;
    if( WPDvrad_iw_p_bl != 0 ) delete WPDvrad_iw_p_bl;
    if( WPDvrad_iw_p_bll != 0 ) delete WPDvrad_iw_p_bll;
    if( WPDvrad_iw_p_lb != 0 ) delete WPDvrad_iw_p_lb;
    if( WPDvrad_iw_p_lc != 0 ) delete WPDvrad_iw_p_lc;
    if( WPDvrad_iw_p_lt != 0 ) delete WPDvrad_iw_p_lt;

    if( WPDtfor_info_window_pos != 0 ) delete WPDtfor_info_window_pos;
    if( WPDtfor_search_panel_pos != 0 ) delete WPDtfor_search_panel_pos;
    if( WPDtfor_info_window_size != 0 ) delete WPDtfor_info_window_size;
    if( WPDtfor_search_panel_size != 0 ) delete WPDtfor_search_panel_size;
    if( WPDtfor_main_window_size != 0 ) delete WPDtfor_main_window_size;

    if( WPDImplMain != 0 ) delete WPDImplMain;

    _rad_mw_w.clear();
    _rad_mw_h.clear();
    _rad_sp_p.clear();
    _rad_sp_w.clear();
    _rad_sp_h.clear();
    _rad_iw_w.clear();
    _rad_iw_h.clear();
    _rad_iw_p.clear();
}


void CTGRWindowPlacementDlg::WPDImpl::CreateParts()
{
    WPDImplMain = new  WSCmainWindow(al::gui::GetAppMainWindow(),"WPDImplMain");
    WPDImplMain->initialize();
    WPDImplMain->setPropertyV(WSNname,"WPDImplMain");
    WPDImplMain->setPropertyV(WSNtitleString,"お手軽ウィンドウ配置ダイアログ");
//    WPDImplMain->setPropertyV(WSNx,(short)100);
//    WPDImplMain->setPropertyV(WSNy,(short)100);
    WPDImplMain->setPropertyV(WSNwidth,(unsigned short)410);
    WPDImplMain->setPropertyV(WSNheight,(unsigned short)480);
    WPDImplMain->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDImplMain->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDImplMain->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDImplMain->setPropertyV(WSNtitleBar,(char)3);
    WPDImplMain->setPropertyV(WSNshadowType,(char)4);
    WPDImplMain->setPropertyV(WSNvis,(WSCbool)0);
    WPDImplMain->setPropertyV(WSNexit,(WSCbool)0);

    WPDtfor_main_window_size = new  WSCtform(WPDImplMain,"WPDtfor_main_window_size");
    WPDtfor_main_window_size->initialize();
    WPDtfor_main_window_size->setPropertyV(WSNtitleString,"メインウィンドウサイズ");
    WPDtfor_main_window_size->setPropertyV(WSNname,"WPDtfor_main_window_size");
    WPDtfor_main_window_size->setPropertyV(WSNx,(short)0);
    WPDtfor_main_window_size->setPropertyV(WSNy,(short)10);
    WPDtfor_main_window_size->setPropertyV(WSNwidth,(unsigned short)400);
    WPDtfor_main_window_size->setPropertyV(WSNheight,(unsigned short)90);
    WPDtfor_main_window_size->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDtfor_main_window_size->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDtfor_main_window_size->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDtfor_main_window_size->setPropertyV(WSNvis,(WSCbool)1);

    WPDvlab_mw_w = new  WSCvlabel(WPDtfor_main_window_size,"WPDvlab_mw_w");
    WPDvlab_mw_w->initialize();
    WPDvlab_mw_w->setPropertyV(WSNshadowType,(char)-1);
    WPDvlab_mw_w->setPropertyV(WSNlabelString,"幅:");
    WPDvlab_mw_w->setPropertyV(WSNalignmentH,(unsigned char)1);
    WPDvlab_mw_w->setPropertyV(WSNname,"WPDvlab_mw_w");
    WPDvlab_mw_w->setPropertyV(WSNvis,(WSCbool)1);
    WPDvlab_mw_w->setPropertyV(WSNx,(short)10);
    WPDvlab_mw_w->setPropertyV(WSNy,(short)20);
    WPDvlab_mw_w->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvlab_mw_h = new  WSCvlabel(WPDtfor_main_window_size,"WPDvlab_mw_h");
    WPDvlab_mw_h->initialize();
    WPDvlab_mw_h->setPropertyV(WSNshadowType,(char)-1);
    WPDvlab_mw_h->setPropertyV(WSNlabelString,"高さ:");
    WPDvlab_mw_h->setPropertyV(WSNalignmentH,(unsigned char)1);
    WPDvlab_mw_h->setPropertyV(WSNname,"WPDvlab_mw_h");
    WPDvlab_mw_h->setPropertyV(WSNvis,(WSCbool)1);
    WPDvlab_mw_h->setPropertyV(WSNx,(short)10);
    WPDvlab_mw_h->setPropertyV(WSNy,(short)50);
    WPDvlab_mw_h->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_w_w = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_w_w");
    WPDvrad_mw_w_w->initialize();
    WPDvrad_mw_w_w->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_w_w->setPropertyV(WSNgroup,"WPDvrad_mw_w");
    WPDvrad_mw_w_w->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_w_w->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_w_w->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_w_w->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_w_w->setPropertyV(WSNlabelString,"広い");
    WPDvrad_mw_w_w->setPropertyV(WSNname,"WPDvrad_mw_w_w");
    WPDvrad_mw_w_w->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_w_w->setPropertyV(WSNx,(short)75);
    WPDvrad_mw_w_w->setPropertyV(WSNy,(short)20);
    WPDvrad_mw_w_w->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_w_mw = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_w_mw");
    WPDvrad_mw_w_mw->initialize();
    WPDvrad_mw_w_mw->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_w_mw->setPropertyV(WSNgroup,"WPDvrad_mw_w");
    WPDvrad_mw_w_mw->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_w_mw->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_w_mw->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_w_mw->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_w_mw->setPropertyV(WSNlabelString,"稍広");
    WPDvrad_mw_w_mw->setPropertyV(WSNname,"WPDvrad_mw_w_mw");
    WPDvrad_mw_w_mw->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_w_mw->setPropertyV(WSNx,(short)140);
    WPDvrad_mw_w_mw->setPropertyV(WSNy,(short)20);
    WPDvrad_mw_w_mw->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_w_m = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_w_m");
    WPDvrad_mw_w_m->initialize();
    WPDvrad_mw_w_m->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_w_m->setPropertyV(WSNgroup,"WPDvrad_mw_w");
    WPDvrad_mw_w_m->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_w_m->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_w_m->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_w_m->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_w_m->setPropertyV(WSNlabelString,"中位");
    WPDvrad_mw_w_m->setPropertyV(WSNname,"WPDvrad_mw_w_m");
    WPDvrad_mw_w_m->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_w_m->setPropertyV(WSNx,(short)205);
    WPDvrad_mw_w_m->setPropertyV(WSNy,(short)20);
    WPDvrad_mw_w_m->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_w_mn = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_w_mn");
    WPDvrad_mw_w_mn->initialize();
    WPDvrad_mw_w_mn->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_w_mn->setPropertyV(WSNgroup,"WPDvrad_mw_w");
    WPDvrad_mw_w_mn->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_w_mn->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_w_mn->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_w_mn->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_w_mn->setPropertyV(WSNlabelString,"稍狭");
    WPDvrad_mw_w_mn->setPropertyV(WSNname,"WPDvrad_mw_w_mn");
    WPDvrad_mw_w_mn->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_w_mn->setPropertyV(WSNx,(short)270);
    WPDvrad_mw_w_mn->setPropertyV(WSNy,(short)20);
    WPDvrad_mw_w_mn->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_w_n = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_w_n");
    WPDvrad_mw_w_n->initialize();
    WPDvrad_mw_w_n->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_w_n->setPropertyV(WSNgroup,"WPDvrad_mw_w");
    WPDvrad_mw_w_n->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_w_n->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_w_n->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_w_n->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_w_n->setPropertyV(WSNlabelString,"狭い");
    WPDvrad_mw_w_n->setPropertyV(WSNname,"WPDvrad_mw_w_n");
    WPDvrad_mw_w_n->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_w_n->setPropertyV(WSNx,(short)335);
    WPDvrad_mw_w_n->setPropertyV(WSNy,(short)20);
    WPDvrad_mw_w_n->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_h_h = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_h_h");
    WPDvrad_mw_h_h->initialize();
    WPDvrad_mw_h_h->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_h_h->setPropertyV(WSNgroup,"WPDvrad_mw_h");
    WPDvrad_mw_h_h->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_h_h->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_h_h->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_h_h->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_h_h->setPropertyV(WSNlabelString,"高い");
    WPDvrad_mw_h_h->setPropertyV(WSNname,"WPDvrad_mw_h_h");
    WPDvrad_mw_h_h->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_h_h->setPropertyV(WSNx,(short)75);
    WPDvrad_mw_h_h->setPropertyV(WSNy,(short)50);
    WPDvrad_mw_h_h->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_h_mh = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_h_mh");
    WPDvrad_mw_h_mh->initialize();
    WPDvrad_mw_h_mh->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_h_mh->setPropertyV(WSNgroup,"WPDvrad_mw_h");
    WPDvrad_mw_h_mh->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_h_mh->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_h_mh->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_h_mh->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_h_mh->setPropertyV(WSNlabelString,"稍高");
    WPDvrad_mw_h_mh->setPropertyV(WSNname,"WPDvrad_mw_h_mh");
    WPDvrad_mw_h_mh->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_h_mh->setPropertyV(WSNx,(short)140);
    WPDvrad_mw_h_mh->setPropertyV(WSNy,(short)50);
    WPDvrad_mw_h_mh->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_h_m = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_h_m");
    WPDvrad_mw_h_m->initialize();
    WPDvrad_mw_h_m->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_h_m->setPropertyV(WSNgroup,"WPDvrad_mw_h");
    WPDvrad_mw_h_m->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_h_m->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_h_m->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_h_m->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_h_m->setPropertyV(WSNlabelString,"中位");
    WPDvrad_mw_h_m->setPropertyV(WSNname,"WPDvrad_mw_h_m");
    WPDvrad_mw_h_m->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_h_m->setPropertyV(WSNx,(short)205);
    WPDvrad_mw_h_m->setPropertyV(WSNy,(short)50);
    WPDvrad_mw_h_m->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_h_ml = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_h_ml");
    WPDvrad_mw_h_ml->initialize();
    WPDvrad_mw_h_ml->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_h_ml->setPropertyV(WSNgroup,"WPDvrad_mw_h");
    WPDvrad_mw_h_ml->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_h_ml->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_h_ml->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_h_ml->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_h_ml->setPropertyV(WSNlabelString,"稍低");
    WPDvrad_mw_h_ml->setPropertyV(WSNname,"WPDvrad_mw_h_ml");
    WPDvrad_mw_h_ml->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_h_ml->setPropertyV(WSNx,(short)270);
    WPDvrad_mw_h_ml->setPropertyV(WSNy,(short)50);
    WPDvrad_mw_h_ml->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_mw_h_l = new  WSCvradio(WPDtfor_main_window_size,"WPDvrad_mw_h_l");
    WPDvrad_mw_h_l->initialize();
    WPDvrad_mw_h_l->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_mw_h_l->setPropertyV(WSNgroup,"WPDvrad_mw_h");
    WPDvrad_mw_h_l->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_mw_h_l->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_mw_h_l->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_mw_h_l->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_mw_h_l->setPropertyV(WSNlabelString,"低い");
    WPDvrad_mw_h_l->setPropertyV(WSNname,"WPDvrad_mw_h_l");
    WPDvrad_mw_h_l->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_mw_h_l->setPropertyV(WSNx,(short)335);
    WPDvrad_mw_h_l->setPropertyV(WSNy,(short)50);
    WPDvrad_mw_h_l->setPropertyV(WSNwidth,(unsigned short)60);
    WPDtfor_info_window_size = new  WSCtform(WPDImplMain,"WPDtfor_info_window_size");
    WPDtfor_info_window_size->initialize();
    WPDtfor_info_window_size->setPropertyV(WSNtitleString,"情報ウィンドウサイズ");
    WPDtfor_info_window_size->setPropertyV(WSNname,"WPDtfor_info_window_size");
    WPDtfor_info_window_size->setPropertyV(WSNx,(short)0);
    WPDtfor_info_window_size->setPropertyV(WSNy,(short)110);
    WPDtfor_info_window_size->setPropertyV(WSNwidth,(unsigned short)400);
    WPDtfor_info_window_size->setPropertyV(WSNheight,(unsigned short)90);
    WPDtfor_info_window_size->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDtfor_info_window_size->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDtfor_info_window_size->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDtfor_info_window_size->setPropertyV(WSNvis,(WSCbool)1);

    WPDvlab_iw_w = new  WSCvlabel(WPDtfor_info_window_size,"WPDvlab_iw_w");
    WPDvlab_iw_w->initialize();
    WPDvlab_iw_w->setPropertyV(WSNshadowType,(char)-1);
    WPDvlab_iw_w->setPropertyV(WSNlabelString,"幅:");
    WPDvlab_iw_w->setPropertyV(WSNalignmentH,(unsigned char)1);
    WPDvlab_iw_w->setPropertyV(WSNname,"WPDvlab_iw_w");
    WPDvlab_iw_w->setPropertyV(WSNvis,(WSCbool)1);
    WPDvlab_iw_w->setPropertyV(WSNx,(short)10);
    WPDvlab_iw_w->setPropertyV(WSNy,(short)20);
    WPDvlab_iw_w->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvlab_iw_h = new  WSCvlabel(WPDtfor_info_window_size,"WPDvlab_iw_h");
    WPDvlab_iw_h->initialize();
    WPDvlab_iw_h->setPropertyV(WSNshadowType,(char)-1);
    WPDvlab_iw_h->setPropertyV(WSNlabelString,"高さ:");
    WPDvlab_iw_h->setPropertyV(WSNalignmentH,(unsigned char)1);
    WPDvlab_iw_h->setPropertyV(WSNname,"WPDvlab_iw_h");
    WPDvlab_iw_h->setPropertyV(WSNvis,(WSCbool)1);
    WPDvlab_iw_h->setPropertyV(WSNx,(short)10);
    WPDvlab_iw_h->setPropertyV(WSNy,(short)50);
    WPDvlab_iw_h->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_iw_w_w = new  WSCvradio(WPDtfor_info_window_size,"WPDvrad_iw_w_w");
    WPDvrad_iw_w_w->initialize();
    WPDvrad_iw_w_w->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_w_w->setPropertyV(WSNgroup,"WPDvrad_iw_w");
    WPDvrad_iw_w_w->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_iw_w_w->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_w_w->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_w_w->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_w_w->setPropertyV(WSNlabelString,"広い");
    WPDvrad_iw_w_w->setPropertyV(WSNname,"WPDvrad_iw_w_w");
    WPDvrad_iw_w_w->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_w_w->setPropertyV(WSNx,(short)75);
    WPDvrad_iw_w_w->setPropertyV(WSNy,(short)20);
    WPDvrad_iw_w_w->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_iw_w_m = new  WSCvradio(WPDtfor_info_window_size,"WPDvrad_iw_w_m");
    WPDvrad_iw_w_m->initialize();
    WPDvrad_iw_w_m->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_w_m->setPropertyV(WSNgroup,"WPDvrad_iw_w");
    WPDvrad_iw_w_m->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_iw_w_m->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_w_m->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_w_m->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_w_m->setPropertyV(WSNlabelString,"中位");
    WPDvrad_iw_w_m->setPropertyV(WSNname,"WPDvrad_iw_w_m");
    WPDvrad_iw_w_m->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_w_m->setPropertyV(WSNx,(short)140);
    WPDvrad_iw_w_m->setPropertyV(WSNy,(short)20);
    WPDvrad_iw_w_m->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_iw_w_n = new  WSCvradio(WPDtfor_info_window_size,"WPDvrad_iw_w_n");
    WPDvrad_iw_w_n->initialize();
    WPDvrad_iw_w_n->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_w_n->setPropertyV(WSNgroup,"WPDvrad_iw_w");
    WPDvrad_iw_w_n->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_iw_w_n->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_w_n->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_w_n->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_w_n->setPropertyV(WSNlabelString,"狭い");
    WPDvrad_iw_w_n->setPropertyV(WSNname,"WPDvrad_iw_w_n");
    WPDvrad_iw_w_n->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_w_n->setPropertyV(WSNx,(short)205);
    WPDvrad_iw_w_n->setPropertyV(WSNy,(short)20);
    WPDvrad_iw_w_n->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_iw_w_sam = new  WSCvradio(WPDtfor_info_window_size,"WPDvrad_iw_w_sam");
    WPDvrad_iw_w_sam->initialize();
    WPDvrad_iw_w_sam->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_w_sam->setPropertyV(WSNgroup,"WPDvrad_iw_w");
    WPDvrad_iw_w_sam->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_iw_w_sam->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_w_sam->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_w_sam->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_w_sam->setPropertyV(WSNlabelString,"メインと同じ");
    WPDvrad_iw_w_sam->setPropertyV(WSNalignmentH,(unsigned char)0);
    WPDvrad_iw_w_sam->setPropertyV(WSNname,"WPDvrad_iw_w_sam");
    WPDvrad_iw_w_sam->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_w_sam->setPropertyV(WSNx,(short)270);
    WPDvrad_iw_w_sam->setPropertyV(WSNy,(short)20);
    WPDvrad_iw_w_sam->setPropertyV(WSNwidth,(unsigned short)120);

    WPDvrad_iw_h_h = new  WSCvradio(WPDtfor_info_window_size,"WPDvrad_iw_h_h");
    WPDvrad_iw_h_h->initialize();
    WPDvrad_iw_h_h->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_h_h->setPropertyV(WSNgroup,"WPDvrad_iw_h");
    WPDvrad_iw_h_h->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_iw_h_h->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_h_h->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_h_h->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_h_h->setPropertyV(WSNlabelString,"高い");
    WPDvrad_iw_h_h->setPropertyV(WSNname,"WPDvrad_iw_h_h");
    WPDvrad_iw_h_h->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_h_h->setPropertyV(WSNx,(short)75);
    WPDvrad_iw_h_h->setPropertyV(WSNy,(short)50);
    WPDvrad_iw_h_h->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_iw_h_m = new  WSCvradio(WPDtfor_info_window_size,"WPDvrad_iw_h_m");
    WPDvrad_iw_h_m->initialize();
    WPDvrad_iw_h_m->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_h_m->setPropertyV(WSNgroup,"WPDvrad_iw_h");
    WPDvrad_iw_h_m->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_iw_h_m->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_h_m->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_h_m->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_h_m->setPropertyV(WSNlabelString,"中位");
    WPDvrad_iw_h_m->setPropertyV(WSNname,"WPDvrad_iw_h_m");
    WPDvrad_iw_h_m->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_h_m->setPropertyV(WSNx,(short)140);
    WPDvrad_iw_h_m->setPropertyV(WSNy,(short)50);
    WPDvrad_iw_h_m->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_iw_h_l = new  WSCvradio(WPDtfor_info_window_size,"WPDvrad_iw_h_l");
    WPDvrad_iw_h_l->initialize();
    WPDvrad_iw_h_l->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_h_l->setPropertyV(WSNgroup,"WPDvrad_iw_h");
    WPDvrad_iw_h_l->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_iw_h_l->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_h_l->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_h_l->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_h_l->setPropertyV(WSNlabelString,"低い");
    WPDvrad_iw_h_l->setPropertyV(WSNname,"WPDvrad_iw_h_l");
    WPDvrad_iw_h_l->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_h_l->setPropertyV(WSNx,(short)205);
    WPDvrad_iw_h_l->setPropertyV(WSNy,(short)50);
    WPDvrad_iw_h_l->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_iw_h_sam = new  WSCvradio(WPDtfor_info_window_size,"WPDvrad_iw_h_sam");
    WPDvrad_iw_h_sam->initialize();
    WPDvrad_iw_h_sam->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_h_sam->setPropertyV(WSNgroup,"WPDvrad_iw_h");
    WPDvrad_iw_h_sam->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_iw_h_sam->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_h_sam->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_h_sam->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_h_sam->setPropertyV(WSNlabelString,"メインと同じ");
    WPDvrad_iw_h_sam->setPropertyV(WSNalignmentH,(unsigned char)0);
    WPDvrad_iw_h_sam->setPropertyV(WSNname,"WPDvrad_iw_h_sam");
    WPDvrad_iw_h_sam->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_h_sam->setPropertyV(WSNx,(short)270);
    WPDvrad_iw_h_sam->setPropertyV(WSNy,(short)50);
    WPDvrad_iw_h_sam->setPropertyV(WSNwidth,(unsigned short)120);

    WPDtfor_search_panel_size = new  WSCtform(WPDImplMain,"WPDtfor_search_panel_size");
    WPDtfor_search_panel_size->initialize();
    WPDtfor_search_panel_size->setPropertyV(WSNtitleString,"検索パネルサイズ");
    WPDtfor_search_panel_size->setPropertyV(WSNname,"WPDtfor_search_panel_size");
    WPDtfor_search_panel_size->setPropertyV(WSNx,(short)0);
    WPDtfor_search_panel_size->setPropertyV(WSNy,(short)210);
    WPDtfor_search_panel_size->setPropertyV(WSNwidth,(unsigned short)400);
    WPDtfor_search_panel_size->setPropertyV(WSNheight,(unsigned short)90);
    WPDtfor_search_panel_size->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDtfor_search_panel_size->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDtfor_search_panel_size->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDtfor_search_panel_size->setPropertyV(WSNvis,(WSCbool)1);

    WPDvlab_sp_w = new  WSCvlabel(WPDtfor_search_panel_size,"WPDvlab_sp_w");
    WPDvlab_sp_w->initialize();
    WPDvlab_sp_w->setPropertyV(WSNshadowType,(char)-1);
    WPDvlab_sp_w->setPropertyV(WSNlabelString,"幅:");
    WPDvlab_sp_w->setPropertyV(WSNalignmentH,(unsigned char)1);
    WPDvlab_sp_w->setPropertyV(WSNname,"WPDvlab_sp_w");
    WPDvlab_sp_w->setPropertyV(WSNvis,(WSCbool)1);
    WPDvlab_sp_w->setPropertyV(WSNx,(short)10);
    WPDvlab_sp_w->setPropertyV(WSNy,(short)20);
    WPDvlab_sp_w->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvlab_sp_h = new  WSCvlabel(WPDtfor_search_panel_size,"WPDvlab_sp_h");
    WPDvlab_sp_h->initialize();
    WPDvlab_sp_h->setPropertyV(WSNshadowType,(char)-1);
    WPDvlab_sp_h->setPropertyV(WSNlabelString,"高さ:");
    WPDvlab_sp_h->setPropertyV(WSNalignmentH,(unsigned char)1);
    WPDvlab_sp_h->setPropertyV(WSNname,"WPDvlab_sp_h");
    WPDvlab_sp_h->setPropertyV(WSNvis,(WSCbool)1);
    WPDvlab_sp_h->setPropertyV(WSNx,(short)10);
    WPDvlab_sp_h->setPropertyV(WSNy,(short)50);
    WPDvlab_sp_h->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_sp_w_w = new  WSCvradio(WPDtfor_search_panel_size,"WPDvrad_sp_w_w");
    WPDvrad_sp_w_w->initialize();
    WPDvrad_sp_w_w->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_w_w->setPropertyV(WSNgroup,"WPDvrad_sp_w");
    WPDvrad_sp_w_w->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_sp_w_w->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_w_w->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_w_w->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_w_w->setPropertyV(WSNlabelString,"広い");
    WPDvrad_sp_w_w->setPropertyV(WSNname,"WPDvrad_sp_w_w");
    WPDvrad_sp_w_w->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_w_w->setPropertyV(WSNx,(short)75);
    WPDvrad_sp_w_w->setPropertyV(WSNy,(short)20);
    WPDvrad_sp_w_w->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_sp_w_m = new  WSCvradio(WPDtfor_search_panel_size,"WPDvrad_sp_w_m");
    WPDvrad_sp_w_m->initialize();
    WPDvrad_sp_w_m->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_w_m->setPropertyV(WSNgroup,"WPDvrad_sp_w");
    WPDvrad_sp_w_m->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_sp_w_m->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_w_m->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_w_m->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_w_m->setPropertyV(WSNlabelString,"中位");
    WPDvrad_sp_w_m->setPropertyV(WSNname,"WPDvrad_sp_w_m");
    WPDvrad_sp_w_m->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_w_m->setPropertyV(WSNx,(short)140);
    WPDvrad_sp_w_m->setPropertyV(WSNy,(short)20);
    WPDvrad_sp_w_m->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_sp_w_n = new  WSCvradio(WPDtfor_search_panel_size,"WPDvrad_sp_w_n");
    WPDvrad_sp_w_n->initialize();
    WPDvrad_sp_w_n->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_w_n->setPropertyV(WSNgroup,"WPDvrad_sp_w");
    WPDvrad_sp_w_n->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_sp_w_n->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_w_n->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_w_n->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_w_n->setPropertyV(WSNlabelString,"狭い");
    WPDvrad_sp_w_n->setPropertyV(WSNname,"WPDvrad_sp_w_n");
    WPDvrad_sp_w_n->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_w_n->setPropertyV(WSNx,(short)205);
    WPDvrad_sp_w_n->setPropertyV(WSNy,(short)20);
    WPDvrad_sp_w_n->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_sp_w_sam = new  WSCvradio(WPDtfor_search_panel_size,"WPDvrad_sp_w_sam");
    WPDvrad_sp_w_sam->initialize();
    WPDvrad_sp_w_sam->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_w_sam->setPropertyV(WSNgroup,"WPDvrad_sp_w");
    WPDvrad_sp_w_sam->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_sp_w_sam->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_w_sam->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_w_sam->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_w_sam->setPropertyV(WSNlabelString,"メインと同じ");
    WPDvrad_sp_w_sam->setPropertyV(WSNalignmentH,(unsigned char)0);
    WPDvrad_sp_w_sam->setPropertyV(WSNname,"WPDvrad_sp_w_sam");
    WPDvrad_sp_w_sam->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_w_sam->setPropertyV(WSNx,(short)270);
    WPDvrad_sp_w_sam->setPropertyV(WSNy,(short)20);
    WPDvrad_sp_w_sam->setPropertyV(WSNwidth,(unsigned short)120);

    WPDvrad_sp_h_h = new  WSCvradio(WPDtfor_search_panel_size,"WPDvrad_sp_h_h");
    WPDvrad_sp_h_h->initialize();
    WPDvrad_sp_h_h->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_h_h->setPropertyV(WSNgroup,"WPDvrad_sp_h");
    WPDvrad_sp_h_h->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_sp_h_h->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_h_h->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_h_h->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_h_h->setPropertyV(WSNlabelString,"高い");
    WPDvrad_sp_h_h->setPropertyV(WSNname,"WPDvrad_sp_h_h");
    WPDvrad_sp_h_h->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_h_h->setPropertyV(WSNx,(short)75);
    WPDvrad_sp_h_h->setPropertyV(WSNy,(short)50);
    WPDvrad_sp_h_h->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_sp_h_m = new  WSCvradio(WPDtfor_search_panel_size,"WPDvrad_sp_h_m");
    WPDvrad_sp_h_m->initialize();
    WPDvrad_sp_h_m->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_h_m->setPropertyV(WSNgroup,"WPDvrad_sp_h");
    WPDvrad_sp_h_m->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_sp_h_m->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_h_m->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_h_m->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_h_m->setPropertyV(WSNlabelString,"中位");
    WPDvrad_sp_h_m->setPropertyV(WSNname,"WPDvrad_sp_h_m");
    WPDvrad_sp_h_m->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_h_m->setPropertyV(WSNx,(short)140);
    WPDvrad_sp_h_m->setPropertyV(WSNy,(short)50);
    WPDvrad_sp_h_m->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_sp_h_l = new  WSCvradio(WPDtfor_search_panel_size,"WPDvrad_sp_h_l");
    WPDvrad_sp_h_l->initialize();
    WPDvrad_sp_h_l->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_h_l->setPropertyV(WSNgroup,"WPDvrad_sp_h");
    WPDvrad_sp_h_l->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_sp_h_l->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_h_l->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_h_l->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_h_l->setPropertyV(WSNlabelString,"低い");
    WPDvrad_sp_h_l->setPropertyV(WSNname,"WPDvrad_sp_h_l");
    WPDvrad_sp_h_l->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_h_l->setPropertyV(WSNx,(short)205);
    WPDvrad_sp_h_l->setPropertyV(WSNy,(short)50);
    WPDvrad_sp_h_l->setPropertyV(WSNwidth,(unsigned short)60);

    WPDvrad_sp_h_sam = new  WSCvradio(WPDtfor_search_panel_size,"WPDvrad_sp_h_sam");
    WPDvrad_sp_h_sam->initialize();
    WPDvrad_sp_h_sam->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_h_sam->setPropertyV(WSNgroup,"WPDvrad_sp_h");
    WPDvrad_sp_h_sam->setPropertyV(WSNselectReset,(WSCbool)1);
    WPDvrad_sp_h_sam->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_h_sam->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_h_sam->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_h_sam->setPropertyV(WSNlabelString,"メインと同じ");
    WPDvrad_sp_h_sam->setPropertyV(WSNalignmentH,(unsigned char)0);
    WPDvrad_sp_h_sam->setPropertyV(WSNname,"WPDvrad_sp_h_sam");
    WPDvrad_sp_h_sam->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_h_sam->setPropertyV(WSNx,(short)270);
    WPDvrad_sp_h_sam->setPropertyV(WSNy,(short)50);
    WPDvrad_sp_h_sam->setPropertyV(WSNwidth,(unsigned short)120);

    WPDtfor_info_window_pos = new  WSCtform(WPDImplMain,"WPDtfor_info_window_pos");
    WPDtfor_info_window_pos->initialize();
    WPDtfor_info_window_pos->setPropertyV(WSNtitleString,"情報ウィンドウ配置");
    WPDtfor_info_window_pos->setPropertyV(WSNname,"WPDtfor_info_window_pos");
    WPDtfor_info_window_pos->setPropertyV(WSNx,(short)1);
    WPDtfor_info_window_pos->setPropertyV(WSNy,(short)310);
    WPDtfor_info_window_pos->setPropertyV(WSNwidth,(unsigned short)150);
    WPDtfor_info_window_pos->setPropertyV(WSNheight,(unsigned short)160);
    WPDtfor_info_window_pos->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDtfor_info_window_pos->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDtfor_info_window_pos->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDtfor_info_window_pos->setPropertyV(WSNvis,(WSCbool)1);

    WPDvlab_iw_main_win = new  WSCvlabel(WPDtfor_info_window_pos,"WPDvlab_iw_main_win");
    WPDvlab_iw_main_win->initialize();
    WPDvlab_iw_main_win->setPropertyV(WSNshadowType,(char)4);
    WPDvlab_iw_main_win->setPropertyV(WSNbackColor,"#ffc0c0");
    WPDvlab_iw_main_win->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvlab_iw_main_win->setPropertyV(WSNbottomShadowColor,"#c08080");
    WPDvlab_iw_main_win->setPropertyV(WSNlabelString,"メイン\\n画面");
    WPDvlab_iw_main_win->setPropertyV(WSNgradation,(unsigned char)1);
    WPDvlab_iw_main_win->setPropertyV(WSNname,"WPDvlab_iw_main_win");
    WPDvlab_iw_main_win->setPropertyV(WSNvis,(WSCbool)1);
    WPDvlab_iw_main_win->setPropertyV(WSNx,(short)40);
    WPDvlab_iw_main_win->setPropertyV(WSNy,(short)50);
    WPDvlab_iw_main_win->setPropertyV(WSNwidth,(unsigned short)72);
    WPDvlab_iw_main_win->setPropertyV(WSNheight,(unsigned short)72);

    WPDvrad_iw_p_tl = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_tl");
    WPDvrad_iw_p_tl->initialize();
    WPDvrad_iw_p_tl->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_tl->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_tl->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_tl->setPropertyV(WSNname,"WPDvrad_iw_p_tl");
    WPDvrad_iw_p_tl->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_tl->setPropertyV(WSNx,(short)40);
    WPDvrad_iw_p_tl->setPropertyV(WSNy,(short)24);
    WPDvrad_iw_p_tl->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_tl->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_tl->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_tl->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_tl->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_tc = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_tc");
    WPDvrad_iw_p_tc->initialize();
    WPDvrad_iw_p_tc->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_tc->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_tc->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_tc->setPropertyV(WSNname,"WPDvrad_iw_p_tc");
    WPDvrad_iw_p_tc->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_tc->setPropertyV(WSNx,(short)66);
    WPDvrad_iw_p_tc->setPropertyV(WSNy,(short)24);
    WPDvrad_iw_p_tc->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_tc->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_tc->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_tc->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_tc->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_tr = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_tr");
    WPDvrad_iw_p_tr->initialize();
    WPDvrad_iw_p_tr->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_tr->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_tr->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_tr->setPropertyV(WSNname,"WPDvrad_iw_p_tr");
    WPDvrad_iw_p_tr->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_tr->setPropertyV(WSNx,(short)92);
    WPDvrad_iw_p_tr->setPropertyV(WSNy,(short)24);
    WPDvrad_iw_p_tr->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_tr->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_tr->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_tr->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_tr->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_trr = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_trr");
    WPDvrad_iw_p_trr->initialize();
    WPDvrad_iw_p_trr->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_trr->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_trr->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_trr->setPropertyV(WSNname,"WPDvrad_iw_p_trr");
    WPDvrad_iw_p_trr->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_trr->setPropertyV(WSNx,(short)114);
    WPDvrad_iw_p_trr->setPropertyV(WSNy,(short)24);
    WPDvrad_iw_p_trr->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_trr->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_trr->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_trr->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_trr->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_tll = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_tll");
    WPDvrad_iw_p_tll->initialize();
    WPDvrad_iw_p_tll->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_tll->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_tll->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_tll->setPropertyV(WSNname,"WPDvrad_iw_p_tll");
    WPDvrad_iw_p_tll->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_tll->setPropertyV(WSNx,(short)16);
    WPDvrad_iw_p_tll->setPropertyV(WSNy,(short)24);
    WPDvrad_iw_p_tll->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_tll->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_tll->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_tll->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_tll->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_rt = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_rt");
    WPDvrad_iw_p_rt->initialize();
    WPDvrad_iw_p_rt->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_rt->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_rt->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_rt->setPropertyV(WSNname,"WPDvrad_iw_p_rt");
    WPDvrad_iw_p_rt->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_rt->setPropertyV(WSNx,(short)114);
    WPDvrad_iw_p_rt->setPropertyV(WSNy,(short)48);
    WPDvrad_iw_p_rt->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_rt->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_rt->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_rt->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_rt->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_rc = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_rc");
    WPDvrad_iw_p_rc->initialize();
    WPDvrad_iw_p_rc->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_rc->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_rc->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_rc->setPropertyV(WSNname,"WPDvrad_iw_p_rc");
    WPDvrad_iw_p_rc->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_rc->setPropertyV(WSNx,(short)114);
    WPDvrad_iw_p_rc->setPropertyV(WSNy,(short)74);
    WPDvrad_iw_p_rc->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_rc->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_rc->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_rc->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_rc->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_rb = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_rb");
    WPDvrad_iw_p_rb->initialize();
    WPDvrad_iw_p_rb->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_rb->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_rb->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_rb->setPropertyV(WSNname,"WPDvrad_iw_p_rb");
    WPDvrad_iw_p_rb->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_rb->setPropertyV(WSNx,(short)114);
    WPDvrad_iw_p_rb->setPropertyV(WSNy,(short)100);
    WPDvrad_iw_p_rb->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_rb->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_rb->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_rb->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_rb->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_brr = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_brr");
    WPDvrad_iw_p_brr->initialize();
    WPDvrad_iw_p_brr->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_brr->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_brr->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_brr->setPropertyV(WSNname,"WPDvrad_iw_p_brr");
    WPDvrad_iw_p_brr->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_brr->setPropertyV(WSNx,(short)114);
    WPDvrad_iw_p_brr->setPropertyV(WSNy,(short)122);
    WPDvrad_iw_p_brr->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_brr->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_brr->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_brr->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_brr->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_br = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_br");
    WPDvrad_iw_p_br->initialize();
    WPDvrad_iw_p_br->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_br->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_br->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_br->setPropertyV(WSNname,"WPDvrad_iw_p_br");
    WPDvrad_iw_p_br->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_br->setPropertyV(WSNx,(short)92);
    WPDvrad_iw_p_br->setPropertyV(WSNy,(short)122);
    WPDvrad_iw_p_br->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_br->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_br->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_br->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_br->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_bc = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_bc");
    WPDvrad_iw_p_bc->initialize();
    WPDvrad_iw_p_bc->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_bc->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_bc->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_bc->setPropertyV(WSNname,"WPDvrad_iw_p_bc");
    WPDvrad_iw_p_bc->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_bc->setPropertyV(WSNx,(short)66);
    WPDvrad_iw_p_bc->setPropertyV(WSNy,(short)122);
    WPDvrad_iw_p_bc->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_bc->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_bc->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_bc->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_bc->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_bl = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_bl");
    WPDvrad_iw_p_bl->initialize();
    WPDvrad_iw_p_bl->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_bl->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_bl->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_bl->setPropertyV(WSNname,"WPDvrad_iw_p_bl");
    WPDvrad_iw_p_bl->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_bl->setPropertyV(WSNx,(short)40);
    WPDvrad_iw_p_bl->setPropertyV(WSNy,(short)122);
    WPDvrad_iw_p_bl->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_bl->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_bl->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_bl->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_bl->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_bll = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_bll");
    WPDvrad_iw_p_bll->initialize();
    WPDvrad_iw_p_bll->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_bll->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_bll->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_bll->setPropertyV(WSNname,"WPDvrad_iw_p_bll");
    WPDvrad_iw_p_bll->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_bll->setPropertyV(WSNx,(short)16);
    WPDvrad_iw_p_bll->setPropertyV(WSNy,(short)122);
    WPDvrad_iw_p_bll->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_bll->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_bll->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_bll->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_bll->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_lb = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_lb");
    WPDvrad_iw_p_lb->initialize();
    WPDvrad_iw_p_lb->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_lb->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_lb->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_lb->setPropertyV(WSNname,"WPDvrad_iw_p_lb");
    WPDvrad_iw_p_lb->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_lb->setPropertyV(WSNx,(short)16);
    WPDvrad_iw_p_lb->setPropertyV(WSNy,(short)100);
    WPDvrad_iw_p_lb->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_lb->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_lb->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_lb->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_lb->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_lc = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_lc");
    WPDvrad_iw_p_lc->initialize();
    WPDvrad_iw_p_lc->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_lc->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_lc->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_lc->setPropertyV(WSNname,"WPDvrad_iw_p_lc");
    WPDvrad_iw_p_lc->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_lc->setPropertyV(WSNx,(short)16);
    WPDvrad_iw_p_lc->setPropertyV(WSNy,(short)74);
    WPDvrad_iw_p_lc->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_lc->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_lc->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_lc->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_lc->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_iw_p_lt = new  WSCvradio(WPDtfor_info_window_pos,"WPDvrad_iw_p_lt");
    WPDvrad_iw_p_lt->initialize();
    WPDvrad_iw_p_lt->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_iw_p_lt->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_iw_p_lt->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_iw_p_lt->setPropertyV(WSNname,"WPDvrad_iw_p_lt");
    WPDvrad_iw_p_lt->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_iw_p_lt->setPropertyV(WSNx,(short)16);
    WPDvrad_iw_p_lt->setPropertyV(WSNy,(short)48);
    WPDvrad_iw_p_lt->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_iw_p_lt->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_iw_p_lt->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_iw_p_lt->setPropertyV(WSNgroup,"WPDvrad_iw_p");
    WPDvrad_iw_p_lt->setPropertyV(WSNselectReset,(WSCbool)1);


    WPDtfor_search_panel_pos = new  WSCtform(WPDImplMain,"WPDtfor_search_panel_pos");
    WPDtfor_search_panel_pos->initialize();
    WPDtfor_search_panel_pos->setPropertyV(WSNtitleString,"検索パネル配置");
    WPDtfor_search_panel_pos->setPropertyV(WSNname,"WPDtfor_search_panel_pos");
    WPDtfor_search_panel_pos->setPropertyV(WSNx,(short)250);
    WPDtfor_search_panel_pos->setPropertyV(WSNy,(short)310);
    WPDtfor_search_panel_pos->setPropertyV(WSNwidth,(unsigned short)150);
    WPDtfor_search_panel_pos->setPropertyV(WSNheight,(unsigned short)160);
    WPDtfor_search_panel_pos->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDtfor_search_panel_pos->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDtfor_search_panel_pos->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDtfor_search_panel_pos->setPropertyV(WSNvis,(WSCbool)1);

    WPDvlab_main_win = new  WSCvlabel(WPDtfor_search_panel_pos,"WPDvlab_main_win");
    WPDvlab_main_win->initialize();
    WPDvlab_main_win->setPropertyV(WSNshadowType,(char)4);
    WPDvlab_main_win->setPropertyV(WSNbackColor,"#ffc0c0");
    WPDvlab_main_win->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvlab_main_win->setPropertyV(WSNbottomShadowColor,"#c08080");
    WPDvlab_main_win->setPropertyV(WSNlabelString,"メイン\\n画面");
    WPDvlab_main_win->setPropertyV(WSNgradation,(unsigned char)1);
    WPDvlab_main_win->setPropertyV(WSNname,"WPDvlab_main_win");
    WPDvlab_main_win->setPropertyV(WSNvis,(WSCbool)1);
    WPDvlab_main_win->setPropertyV(WSNx,(short)40);
    WPDvlab_main_win->setPropertyV(WSNy,(short)50);
    WPDvlab_main_win->setPropertyV(WSNwidth,(unsigned short)72);
    WPDvlab_main_win->setPropertyV(WSNheight,(unsigned short)72);

    WPDvrad_sp_p_tl = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_tl");
    WPDvrad_sp_p_tl->initialize();
    WPDvrad_sp_p_tl->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_tl->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_tl->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_tl->setPropertyV(WSNname,"WPDvrad_sp_p_tl");
    WPDvrad_sp_p_tl->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_tl->setPropertyV(WSNx,(short)40);
    WPDvrad_sp_p_tl->setPropertyV(WSNy,(short)24);
    WPDvrad_sp_p_tl->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_tl->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_tl->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_tl->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_tl->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_tc = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_tc");
    WPDvrad_sp_p_tc->initialize();
    WPDvrad_sp_p_tc->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_tc->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_tc->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_tc->setPropertyV(WSNname,"WPDvrad_sp_p_tc");
    WPDvrad_sp_p_tc->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_tc->setPropertyV(WSNx,(short)66);
    WPDvrad_sp_p_tc->setPropertyV(WSNy,(short)24);
    WPDvrad_sp_p_tc->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_tc->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_tc->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_tc->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_tc->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_tr = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_tr");
    WPDvrad_sp_p_tr->initialize();
    WPDvrad_sp_p_tr->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_tr->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_tr->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_tr->setPropertyV(WSNname,"WPDvrad_sp_p_tr");
    WPDvrad_sp_p_tr->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_tr->setPropertyV(WSNx,(short)92);
    WPDvrad_sp_p_tr->setPropertyV(WSNy,(short)24);
    WPDvrad_sp_p_tr->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_tr->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_tr->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_tr->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_tr->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_trr = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_trr");
    WPDvrad_sp_p_trr->initialize();
    WPDvrad_sp_p_trr->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_trr->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_trr->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_trr->setPropertyV(WSNname,"WPDvrad_sp_p_trr");
    WPDvrad_sp_p_trr->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_trr->setPropertyV(WSNx,(short)114);
    WPDvrad_sp_p_trr->setPropertyV(WSNy,(short)24);
    WPDvrad_sp_p_trr->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_trr->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_trr->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_trr->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_trr->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_tll = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_tll");
    WPDvrad_sp_p_tll->initialize();
    WPDvrad_sp_p_tll->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_tll->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_tll->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_tll->setPropertyV(WSNname,"WPDvrad_sp_p_tll");
    WPDvrad_sp_p_tll->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_tll->setPropertyV(WSNx,(short)16);
    WPDvrad_sp_p_tll->setPropertyV(WSNy,(short)24);
    WPDvrad_sp_p_tll->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_tll->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_tll->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_tll->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_tll->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_rt = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_rt");
    WPDvrad_sp_p_rt->initialize();
    WPDvrad_sp_p_rt->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_rt->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_rt->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_rt->setPropertyV(WSNname,"WPDvrad_sp_p_rt");
    WPDvrad_sp_p_rt->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_rt->setPropertyV(WSNx,(short)114);
    WPDvrad_sp_p_rt->setPropertyV(WSNy,(short)48);
    WPDvrad_sp_p_rt->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_rt->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_rt->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_rt->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_rt->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_rc = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_rc");
    WPDvrad_sp_p_rc->initialize();
    WPDvrad_sp_p_rc->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_rc->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_rc->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_rc->setPropertyV(WSNname,"WPDvrad_sp_p_rc");
    WPDvrad_sp_p_rc->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_rc->setPropertyV(WSNx,(short)114);
    WPDvrad_sp_p_rc->setPropertyV(WSNy,(short)74);
    WPDvrad_sp_p_rc->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_rc->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_rc->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_rc->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_rc->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_rb = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_rb");
    WPDvrad_sp_p_rb->initialize();
    WPDvrad_sp_p_rb->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_rb->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_rb->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_rb->setPropertyV(WSNname,"WPDvrad_sp_p_rb");
    WPDvrad_sp_p_rb->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_rb->setPropertyV(WSNx,(short)114);
    WPDvrad_sp_p_rb->setPropertyV(WSNy,(short)100);
    WPDvrad_sp_p_rb->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_rb->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_rb->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_rb->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_rb->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_brr = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_brr");
    WPDvrad_sp_p_brr->initialize();
    WPDvrad_sp_p_brr->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_brr->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_brr->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_brr->setPropertyV(WSNname,"WPDvrad_sp_p_brr");
    WPDvrad_sp_p_brr->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_brr->setPropertyV(WSNx,(short)114);
    WPDvrad_sp_p_brr->setPropertyV(WSNy,(short)122);
    WPDvrad_sp_p_brr->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_brr->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_brr->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_brr->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_brr->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_br = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_br");
    WPDvrad_sp_p_br->initialize();
    WPDvrad_sp_p_br->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_br->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_br->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_br->setPropertyV(WSNname,"WPDvrad_sp_p_br");
    WPDvrad_sp_p_br->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_br->setPropertyV(WSNx,(short)92);
    WPDvrad_sp_p_br->setPropertyV(WSNy,(short)122);
    WPDvrad_sp_p_br->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_br->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_br->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_br->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_br->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_bc = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_bc");
    WPDvrad_sp_p_bc->initialize();
    WPDvrad_sp_p_bc->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_bc->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_bc->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_bc->setPropertyV(WSNname,"WPDvrad_sp_p_bc");
    WPDvrad_sp_p_bc->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_bc->setPropertyV(WSNx,(short)66);
    WPDvrad_sp_p_bc->setPropertyV(WSNy,(short)122);
    WPDvrad_sp_p_bc->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_bc->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_bc->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_bc->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_bc->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_bl = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_bl");
    WPDvrad_sp_p_bl->initialize();
    WPDvrad_sp_p_bl->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_bl->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_bl->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_bl->setPropertyV(WSNname,"WPDvrad_sp_p_bl");
    WPDvrad_sp_p_bl->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_bl->setPropertyV(WSNx,(short)40);
    WPDvrad_sp_p_bl->setPropertyV(WSNy,(short)122);
    WPDvrad_sp_p_bl->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_bl->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_bl->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_bl->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_bl->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_bll = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_bll");
    WPDvrad_sp_p_bll->initialize();
    WPDvrad_sp_p_bll->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_bll->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_bll->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_bll->setPropertyV(WSNname,"WPDvrad_sp_p_bll");
    WPDvrad_sp_p_bll->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_bll->setPropertyV(WSNx,(short)16);
    WPDvrad_sp_p_bll->setPropertyV(WSNy,(short)122);
    WPDvrad_sp_p_bll->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_bll->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_bll->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_bll->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_bll->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_lb = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_lb");
    WPDvrad_sp_p_lb->initialize();
    WPDvrad_sp_p_lb->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_lb->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_lb->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_lb->setPropertyV(WSNname,"WPDvrad_sp_p_lb");
    WPDvrad_sp_p_lb->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_lb->setPropertyV(WSNx,(short)16);
    WPDvrad_sp_p_lb->setPropertyV(WSNy,(short)100);
    WPDvrad_sp_p_lb->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_lb->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_lb->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_lb->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_lb->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_lc = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_lc");
    WPDvrad_sp_p_lc->initialize();
    WPDvrad_sp_p_lc->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_lc->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_lc->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_lc->setPropertyV(WSNname,"WPDvrad_sp_p_lc");
    WPDvrad_sp_p_lc->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_lc->setPropertyV(WSNx,(short)16);
    WPDvrad_sp_p_lc->setPropertyV(WSNy,(short)74);
    WPDvrad_sp_p_lc->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_lc->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_lc->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_lc->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_lc->setPropertyV(WSNselectReset,(WSCbool)1);

    WPDvrad_sp_p_lt = new  WSCvradio(WPDtfor_search_panel_pos,"WPDvrad_sp_p_lt");
    WPDvrad_sp_p_lt->initialize();
    WPDvrad_sp_p_lt->setPropertyV(WSNbackColor,"#c0c0ff");
    WPDvrad_sp_p_lt->setPropertyV(WSNtopShadowColor,"#ffffff");
    WPDvrad_sp_p_lt->setPropertyV(WSNbottomShadowColor,"#8080c0");
    WPDvrad_sp_p_lt->setPropertyV(WSNname,"WPDvrad_sp_p_lt");
    WPDvrad_sp_p_lt->setPropertyV(WSNvis,(WSCbool)1);
    WPDvrad_sp_p_lt->setPropertyV(WSNx,(short)16);
    WPDvrad_sp_p_lt->setPropertyV(WSNy,(short)48);
    WPDvrad_sp_p_lt->setPropertyV(WSNwidth,(unsigned short)24);
    WPDvrad_sp_p_lt->setPropertyV(WSNheight,(unsigned short)24);
    WPDvrad_sp_p_lt->setPropertyV(WSNunique,(WSCbool)1);
    WPDvrad_sp_p_lt->setPropertyV(WSNgroup,"WPDvrad_sp_p");
    WPDvrad_sp_p_lt->setPropertyV(WSNselectReset,(WSCbool)1);
}

void CTGRWindowPlacementDlg::WPDImpl::SetupVectors()
{
    _rad_mw_w.push_back(WPDvrad_mw_w_w);
    _rad_mw_w.push_back(WPDvrad_mw_w_mw);
    _rad_mw_w.push_back(WPDvrad_mw_w_m);
    _rad_mw_w.push_back(WPDvrad_mw_w_mn);
    _rad_mw_w.push_back(WPDvrad_mw_w_n);

    _rad_mw_h.push_back(WPDvrad_mw_h_h);
    _rad_mw_h.push_back(WPDvrad_mw_h_mh);
    _rad_mw_h.push_back(WPDvrad_mw_h_m);
    _rad_mw_h.push_back(WPDvrad_mw_h_ml);
    _rad_mw_h.push_back(WPDvrad_mw_h_l);

    _rad_sp_w.push_back(WPDvrad_sp_w_w);
    _rad_sp_w.push_back(WPDvrad_sp_w_m);
    _rad_sp_w.push_back(WPDvrad_sp_w_n);
    _rad_sp_w.push_back(WPDvrad_sp_w_sam);

    _rad_sp_h.push_back(WPDvrad_sp_h_h);
    _rad_sp_h.push_back(WPDvrad_sp_h_m);
    _rad_sp_h.push_back(WPDvrad_sp_h_l);
    _rad_sp_h.push_back(WPDvrad_sp_h_sam);

    _rad_iw_w.push_back(WPDvrad_iw_w_w);
    _rad_iw_w.push_back(WPDvrad_iw_w_m);
    _rad_iw_w.push_back(WPDvrad_iw_w_n);
    _rad_iw_w.push_back(WPDvrad_iw_w_sam);

    _rad_iw_h.push_back(WPDvrad_iw_h_h);
    _rad_iw_h.push_back(WPDvrad_iw_h_m);
    _rad_iw_h.push_back(WPDvrad_iw_h_l);
    _rad_iw_h.push_back(WPDvrad_iw_h_sam);

    _rad_sp_p.push_back(WPDvrad_sp_p_tl);
    _rad_sp_p.push_back(WPDvrad_sp_p_tc);
    _rad_sp_p.push_back(WPDvrad_sp_p_tr);
    _rad_sp_p.push_back(WPDvrad_sp_p_trr);
    _rad_sp_p.push_back(WPDvrad_sp_p_tll);
    _rad_sp_p.push_back(WPDvrad_sp_p_rt);
    _rad_sp_p.push_back(WPDvrad_sp_p_rc);
    _rad_sp_p.push_back(WPDvrad_sp_p_rb);
    _rad_sp_p.push_back(WPDvrad_sp_p_brr);
    _rad_sp_p.push_back(WPDvrad_sp_p_br);
    _rad_sp_p.push_back(WPDvrad_sp_p_bc);
    _rad_sp_p.push_back(WPDvrad_sp_p_bl);
    _rad_sp_p.push_back(WPDvrad_sp_p_bll);
    _rad_sp_p.push_back(WPDvrad_sp_p_lb);
    _rad_sp_p.push_back(WPDvrad_sp_p_lc);
    _rad_sp_p.push_back(WPDvrad_sp_p_lt);

    _rad_iw_p.push_back(WPDvrad_iw_p_tl);
    _rad_iw_p.push_back(WPDvrad_iw_p_tc);
    _rad_iw_p.push_back(WPDvrad_iw_p_tr);
    _rad_iw_p.push_back(WPDvrad_iw_p_trr);
    _rad_iw_p.push_back(WPDvrad_iw_p_tll);
    _rad_iw_p.push_back(WPDvrad_iw_p_rt);
    _rad_iw_p.push_back(WPDvrad_iw_p_rc);
    _rad_iw_p.push_back(WPDvrad_iw_p_rb);
    _rad_iw_p.push_back(WPDvrad_iw_p_brr);
    _rad_iw_p.push_back(WPDvrad_iw_p_br);
    _rad_iw_p.push_back(WPDvrad_iw_p_bc);
    _rad_iw_p.push_back(WPDvrad_iw_p_bl);
    _rad_iw_p.push_back(WPDvrad_iw_p_bll);
    _rad_iw_p.push_back(WPDvrad_iw_p_lb);
    _rad_iw_p.push_back(WPDvrad_iw_p_lc);
    _rad_iw_p.push_back(WPDvrad_iw_p_lt);
}


void CTGRWindowPlacementDlg::WPDImpl::SetupEventProcedures()
{
    std::vector<WSCvradio*>::const_iterator	it;

    for( it = _rad_mw_w.begin(); it != _rad_mw_w.end(); ++it ) {
        (*it)->setStatus(False);
        m_oi_map.MemorizeInstanceForTheObject((*it),this);
        (*it)->addProcedureV("ep_rad_value_ch","ep_rad_value_ch",ep_rad_value_ch,
                             WSEV_VALUE_CH);
    }

    for( it = _rad_mw_h.begin(); it != _rad_mw_h.end(); ++it ) {
        (*it)->setStatus(False);
        m_oi_map.MemorizeInstanceForTheObject((*it),this);
        (*it)->addProcedureV("ep_rad_value_ch","ep_rad_value_ch",ep_rad_value_ch,
                             WSEV_VALUE_CH);
    }

    for( it = _rad_sp_w.begin(); it != _rad_sp_w.end(); ++it ) {
        (*it)->setStatus(False);
        m_oi_map.MemorizeInstanceForTheObject((*it),this);
        (*it)->addProcedureV("ep_rad_value_ch","ep_rad_value_ch",ep_rad_value_ch,
                             WSEV_VALUE_CH);
    }

    for( it = _rad_sp_h.begin(); it != _rad_sp_h.end(); ++it ) {
        (*it)->setStatus(False);
        m_oi_map.MemorizeInstanceForTheObject((*it),this);
        (*it)->addProcedureV("ep_rad_value_ch","ep_rad_value_ch",ep_rad_value_ch,
                             WSEV_VALUE_CH);
    }


    for( it = _rad_iw_w.begin(); it != _rad_iw_w.end(); ++it ) {
        (*it)->setStatus(False);
        m_oi_map.MemorizeInstanceForTheObject((*it),this);
        (*it)->addProcedureV("ep_rad_value_ch","ep_rad_value_ch",ep_rad_value_ch,
                             WSEV_VALUE_CH);
    }

    for( it = _rad_iw_h.begin(); it != _rad_iw_h.end(); ++it ) {
        (*it)->setStatus(False);
        m_oi_map.MemorizeInstanceForTheObject((*it),this);
        (*it)->addProcedureV("ep_rad_value_ch","ep_rad_value_ch",ep_rad_value_ch,
                             WSEV_VALUE_CH);
    }

    for( it = _rad_sp_p.begin(); it != _rad_sp_p.end(); ++it ) {
        (*it)->setStatus(False);
        m_oi_map.MemorizeInstanceForTheObject((*it),this);
        (*it)->addProcedureV("ep_rad_value_ch","ep_rad_value_ch",ep_rad_value_ch,
                             WSEV_VALUE_CH);
    }

    for( it = _rad_iw_p.begin(); it != _rad_iw_p.end(); ++it ) {
        (*it)->setStatus(False);
        m_oi_map.MemorizeInstanceForTheObject((*it),this);
        (*it)->addProcedureV("ep_rad_value_ch","ep_rad_value_ch",ep_rad_value_ch,
                             WSEV_VALUE_CH);
    }
}


} /* namespace tgrapp */

